@@ -79,12 +79,13 @@
 #' @param na.rm if \code{TRUE}, observations with \code{NA} values are deleted 
 #' from the population and sample data. For the EBP procedure complete observations  
 #' are required. Defaults to \code{FALSE}. 
-#' @return An object of class "emdi" that provides estimators for regional
+#' @return An object of class "emdi", "model", "ebp" that provides estimators for regional
 #' disaggregated indicators and optionally corresponding MSE estimates. Generic
-#' functions such as \code{\link{estimators}}, \code{\link{print}}, 
-#' \code{\link{plot}} and \code{\link{summary}} have methods that can be used
-#' to obtain further information. See \code{\link{emdiObject}} for descriptions
-#' of components of objects of class "emdi".
+#' functions such as \code{\link{compare_plot}}, \code{\link{estimators}},  
+#' \code{\link{print}}, \code{\link{plot}} and \code{\link{summary}} have 
+#' methods that can be used to obtain further information. See 
+#' \code{\link{emdiObject}} for descriptions of components of objects 
+#' of class "emdi".
 #' @details For Monte-Carlo approximations and in the parametric bootstrap
 #' approach random number generation is used. Thus, a seed is set by the 
 #' argument \code{seed}. \cr \cr
@@ -110,7 +111,7 @@
 #' \code{\link{estimators.emdi}}, \code{\link{print.emdi}}, \code{\link{plot.emdi}},
 #' \code{\link{summary.emdi}}
 #' @examples
-#' \dontrun{
+#' \donttest{
 #' # Loading data - population and sample data
 #' data("eusilcA_pop")
 #' data("eusilcA_smp")
@@ -199,7 +200,7 @@ ebp <- function(fixed,
                               smp_domains      = smp_domains,
                               custom_indicator = custom_indicator,
                               fixed            = fixed,
-                              threshold         = threshold,
+                              threshold        = threshold,
                               na.rm            = na.rm
                               )
 
@@ -280,6 +281,6 @@ ebp <- function(fixed,
   if (cpus > 1 && parallel_mode != "socket") {
     RNGkind(RNG_kind[1]) # restoring RNG type
   }
-  class(ebp_out) <- c("emdi", "model")
+  class(ebp_out) <- c("emdi", "model", "ebp")
   return(ebp_out)
 }
